@@ -1,7 +1,9 @@
 import os
 from os import listdir
+import pkg_resources
 
-HTML_TEMPLATE_PATH = 'kraken_html/html_template'
+
+HTML_TEMPLATE_PATH = 'html_template'
 
 html_templates = {}
 
@@ -37,8 +39,10 @@ class Html_bootstrap:
         for i in files:
             item = i.replace('.txt', '')
             filename = HTML_TEMPLATE_PATH + '/' + i
-            f = open(filename, "r")
-            html_templates[item] = f.read()
+            
+        
+            stream = pkg_resources.resource_stream(__name__, filename)
+            html_templates[item] = stream.read()
         return
 
 
