@@ -1,6 +1,8 @@
 
 from kraken_html.html_bootstrap import Html_bootstrap as HTMLBOOT
 from kraken_html.kraken_record_html import Kraken_record_html as KR_HTML
+import pkg_resources
+
 
 import json
 import requests
@@ -262,8 +264,9 @@ class Kraken_html:
         filename = CONTENT_TEMPLATE + page + '_' + language + '.json'
 
         # Load file
-        f = open(filename, "r")
-        content = f.read()
+        stream = pkg_resources.resource_stream(__name__, filename)
+
+        content = stream.read()
 
         # COnvert \n to <br>
         content = content.replace('\\n', '<br>')
